==> data-miner-manager-1.9.0-4.13.0-173871-sources.jar: org/gcube/portlets/user/dataminermanager/client/parametersfield/StringItem.java <==
package org.gcube.portlets.user.dataminermanager.client.parametersfield;

import org.gcube.portlets.user.dataminermanager.client.DataMinerManager;
import org.gcube.data.analysis.dataminermanagercl.shared.parameters.ObjectParameter;

import com.sencha.gxt.core.client.util.Margins;
import com.sencha.gxt.widget.core.client.button.TextButton;
import com.sencha.gxt.widget.core.client.container.HBoxLayoutContainer;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.form.TextField;

/**
 * 
 * @author Giancarlo Panichi
 * 
 *
 */
public class StringItem extends HBoxLayoutContainer {
	private ListStringFld parent;
	private TextField field;
	private TextButton addBtn;
	private TextButton removeBtn;

	/**
	 * 
	 * @param parent parend
	 * @param objectParameter object parameter
	 * @param first true if is first
	 */
	public StringItem(ListStringFld parent, ObjectParameter objectParameter, boolean first) {
		super();
		this.parent=parent;
		create(objectParameter,first);	
	}
	
	private void create( ObjectParameter objectParameter, boolean first){
		field = new TextField();
		field.setAllowBlank(false);

		addBtn = new TextButton("");

		addBtn.setIcon(DataMinerManager.resources.add());

		addBtn.addSelectHandler(new SelectEvent.SelectHandler() {

			@Override
			public void onSelect(SelectEvent event) {
				parent.addField(StringItem.this);
				

			}
		});

		removeBtn = new TextButton("");

		removeBtn.setIcon(DataMinerManager.resources.cancel());

		removeBtn.addSelectHandler(new SelectEvent.SelectHandler() {

			@Override
			public void onSelect(SelectEvent event) {
				parent.removeField(StringItem.this);
				

			}
		});

		removeBtn.setVisible(!first);

		setPack(BoxLayoutPack.START);
		setEnableOverflow(false);
		add(field, new BoxLayoutData(new Margins()));
		add(addBtn, new BoxLayoutData(new Margins()));
		add(removeBtn, new BoxLayoutData(new Margins()));

		forceLayout();
	}

	public void showCancelButton() {
		removeBtn.setVisible(true);
	}

	public void hideCancelButton() {
		removeBtn.setVisible(false);
	}

	public String getValue() {
		return field.getCurrentValue();
	}

	public boolean isValid() {
		return field.isValid();
	}

}

==> data-miner-manager-1.13.0-20221116.165054-5-sources.jar: org/gcube/portlets/user/dataminermanager/client/parametersfield/StringItem.java <==
package org.gcube.portlets.user.dataminermanager.client.parametersfield;

import org.gcube.portlets.user.dataminermanager.client.DataMinerManager;
import org.gcube.data.analysis.dataminermanagercl.shared.parameters.ObjectParameter;

import com.sencha.gxt.core.client.util.Margins;
import com.sencha.gxt.widget.core.client.button.TextButton;
import com.sencha.gxt.widget.core.client.container.HBoxLayoutContainer;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.form.TextField;

/**
 * 
 * @author Giancarlo Panichi
 * 
 *
 */
public class StringItem extends HBoxLayoutContainer {
	private ListStringFld parent;
	private TextField field;
	private TextButton addBtn;
	private TextButton removeBtn;

	/**
	 * 
	 * @param parent parend
	 * @param objectParameter object parameter
	 * @param first true if is first
	 */
	public StringItem(ListStringFld parent, ObjectParameter objectParameter, boolean first) {
		super();
		this.parent=parent;
		create(objectParameter,first);	
	}
	
	private void create( ObjectParameter objectParameter, boolean first){
		field = new TextField();
		field.setAllowBlank(false);

		if(objectParameter!=null && objectParameter.getDefaultValue()!=null &&
				!objectParameter.getDefaultValue().isEmpty()) {
			field.setValue(objectParameter.getDefaultValue());
		}
		
		addBtn = new TextButton("");

		addBtn.setIcon(DataMinerManager.resources.add());

		addBtn.addSelectHandler(new SelectEvent.SelectHandler() {

			@Override
			public void onSelect(SelectEvent event) {
				parent.addField(StringItem.this);
				

			}
		});

		removeBtn = new TextButton("");

		removeBtn.setIcon(DataMinerManager.resources.cancel());

		removeBtn.addSelectHandler(new SelectEvent.SelectHandler() {

			@Override
			public void onSelect(SelectEvent event) {
				parent.removeField(StringItem.this);
				

			}
		});

		removeBtn.setVisible(!first);

		setPack(BoxLayoutPack.START);
		setEnableOverflow(false);
		add(field, new BoxLayoutData(new Margins()));
		add(addBtn, new BoxLayoutData(new Margins()));
		add(removeBtn, new BoxLayoutData(new Margins()));

		forceLayout();
	}

	public void showCancelButton() {
		removeBtn.setVisible(true);
	}

	public void hideCancelButton() {
		removeBtn.setVisible(false);
	}

	public String getValue() {
		return field.getCurrentValue();
	}

	public boolean isValid() {
		return field.isValid();
	}

}
